@@ -25,11 +25,11 @@ Marketplace::Ebay - Making API calls to eBay (with XSD validation)
 
 =head1 VERSION
 
-Version 0.15
+Version 0.16
 
 =cut
 
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 
 =head1 SYNOPSIS
 
@@ -249,7 +249,7 @@ sub log_event {
     my ($self, @strings) = @_;
     if (my $file = $self->log_file) {
         open (my $fh, '>>', $file) or die "Cannot open $file $!";
-        my $now = "\n" . localtime . "\n";
+        my $now = "\n" . localtime() . "\n";
         print $fh $now, @strings;
         close $fh or die "Cannot close $file $!";
     }
